#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
IG Markets API Library for Python
https://github.com/ig-python/ig-markets-api-python-library/
by Femto Trader - https://github.com/femtotrader
"""

from __future__ import absolute_import, division, print_function


from .version import (
    __author__,
    __copyright__,
    __credits__,
    __license__,
    __version__,
    __maintainer__,
    __author_email__,
    __status__,
    __url__,
)

from .rest import IGService
from .stream import IGStreamService

__all__ = [
    "IGService",
    "IGStreamService",
    "__author__",
    "__copyright__",
    "__credits__",
    "__license__",
    "__version__",
    "__maintainer__",
    "__author_email__",
    "__status__",
    "__url__",
]



#!/usr/bin/env python
# -*- coding:utf-8 -*-

import os
import logging

ENV_VAR_ROOT = "IG_SERVICE"
CONFIG_FILE_NAME = "trading_ig_config.py"

logger = logging.getLogger(__name__)


class ConfigEnvVar(object):
    def __init__(self, env_var_base):
        self.ENV_VAR_BASE = env_var_base

    def _env_var(self, key):
        return self.ENV_VAR_BASE + "_" + key.upper()

    def get(self, key, default_value=None):
        env_var = self._env_var(key)
        return os.environ.get(env_var, default_value)

    def __getattr__(self, key):
        env_var = self._env_var(key)
        try:
            return os.environ[env_var]
        except KeyError:
            raise Exception("Environment variable '%s' doesn't exist" % env_var)


try:
    from trading_ig_config import config

    logger.info("import config from %s" % CONFIG_FILE_NAME)
except Exception:
    logger.warning("can't import config from config file")
    try:
        config = ConfigEnvVar(ENV_VAR_ROOT)
        logger.info("import config from environment variables '%s_...'" % ENV_VAR_ROOT)
    except Exception:
        logger.warning("can't import config from environment variables")
        raise (
            """Can't import config - you might create a '%s' filename or use
environment variables such as '%s_...'"""
            % (CONFIG_FILE_NAME, ENV_VAR_ROOT)
        )



__author__ = "Femto Trader"
__author_email__ = "femto.trader@gmail.com"
__copyright__ = "Copyright 2015-2021"
__credits__ = [""]
__license__ = "BSD"
__version__ = "0.0.12"
__maintainer__ = "Andy Geach"
__status__ = "Development"
__url__ = "https://github.com/ig-python/ig-markets-api-python-library"
